@@ -11,7 +11,7 @@ from migrate.run import driver
 
 class TestAddDropColumn(fixture.DB):
     level=fixture.DB.CONNECT
-    meta = DynamicMetaData()
+    meta = MetaData()
     # We'll be adding the 'data' column
     table_name = 'tmp_adddropcol'
     table_int = 0
@@ -25,7 +25,7 @@ class TestAddDropColumn(fixture.DB):
             Column('id',Integer,primary_key=True),
         )
         super(TestAddDropColumn,self).setUp()
-        self.meta.connect(self.engine)
+        self.meta.bind = self.engine
         if self.engine.has_table(self.table.name):
             self.table.drop()
         self.table.create()
@@ -185,10 +185,10 @@ class TestAddDropColumn(fixture.DB):
 
 class TestRename(fixture.DB):
     level=fixture.DB.CONNECT
-    meta = DynamicMetaData()
+    meta = MetaData()
 
     def setUp(self):
-        self.meta.connect(self.engine)
+        self.meta.bind = self.engine #self.meta.connect(self.engine)
 
     @fixture.usedb()
     def test_rename_table(self):
@@ -276,7 +276,7 @@ class TestColumnChange(fixture.DB):
 
     def setUp(self):
         fixture.DB.setUp(self)
-        self.meta = BoundMetaData(self.engine)
+        self.meta = MetaData(self.engine)
         self.table = Table(self.table_name,self.meta,
             Column('id',Integer,primary_key=True),
             Column('data',String(40),PassiveDefault("tluafed"),nullable=True),
